# sb::Plugin::PageTitle
# == written by T.Otani <takuya.otani@gmail.com> ===
# == Copyright (C) 2004 SimpleBoxes/SerendipityNZ ==

use strict;

# ======================================
package sb::Plugin::PageTitle;
# --------------------------------------
# // configuration for inheritance / dependancy
use sb::Plugin ();
# --------------------------------------
# // initialization for plugin
sb::Plugin->register_plugin(
	'lang' => {
		'ja' => 'euc',
		'en' => 'ascii',
	},
	'text' => {
		'type'    => 'content',
		'name'    => 'Page Title',
		'text'    => 'added toppage and nontop block, and page_title tag.',
		'author'  => 'takkyun',
		'detail'  => 'http://serenebach.net/',
		'version' => '0.03',
		# 0.03 [2007/05/25] fixed a bug to output mobile content corrctly
		# 0.02 [2007/05/03] fixed a bug to output feed correctly
		# 0.01 [2007/05/01] fixed a bug
		# 0.00 [2007/04/25] generated
	},
	'file' => 'pagetitle.txt',
	'data' => undef,
);
sb::Plugin->register_content_module(
	'type'     => 'main',
	'callback' => \&sb::Content::PageTitle::_nontop,
	'name'     => 'nontop',
	'field'    => 'nontop',
);
sb::Plugin->register_content_module(
	'type'     => 'main',
	'callback' => \&sb::Content::PageTitle::_toppage,
	'name'     => 'toppage',
	'field'    => 'toppage',
);
sb::Plugin->register_content_module(
	'type'     => 'main',
	'callback' => \&sb::Content::PageTitle::_pagetitle,
	'name'     => 'pagetitle',
	'field'    => '_main',
);
# ======================================
package sb::Content::PageTitle;
use sb::Content ();
# --------------------------------------
# // callbacks
sub _toppage
{
	my $cms = shift;
	my %var = @_;
	return(1) if ($var{'mode'} eq 'page' and $var{'page'} == 0);
	return(0);
}
sub _nontop
{
	my $cms = shift;
	my %var = @_;
	return(0) if ($var{'mode'} eq 'page' and $var{'page'} == 0);
	return(1);
}
sub _pagetitle
{
	my $cms = shift;
	my %var = @_;
	my $title = '';
	if ($var{'mode'} eq 'arc')
	{
		my @check = ($var{'cond'} =~ /(\d\d\d\d)(\d\d)(\d\d)?/);
		pop(@check) if ($check[-1] eq '');
		$title .= $var{'lang'}->string('pagetitle_archive_prefix');
		$title .= join('/',@check);
		$title .= $var{'lang'}->string('pagetitle_archive_postfix');
	}
	elsif ($var{'mode'} eq 'srch')
	{
		$title .= $var{'lang'}->string('pagetitle_search_prefix');
		$title .= $var{'cond'};
		$title .= $var{'lang'}->string('pagetitle_search_postfix');
	}
	elsif ($var{'mode'} eq 'cat')
	{
		$title = $var{'cat'}->{$var{'id'}}->name();
	}
	elsif ($var{'mode'} eq 'ent' and $var{'entry'} and $var{'entry'}->[0])
	{
		$title = $var{'entry'}->[0]->subj();
	}
	elsif ($var{'mode'} eq 'user')
	{
		my $user = sb::Data->load('User','id'=>$var{'id'});
		$title = ($user) ? $user->real() : $var{'blog'}->title();
	}
	else
	{
		$title = $var{'blog'}->title();
	}
	$cms->num(0);
	$cms->tag('page_title'=>$title);
	return &_default_handler($cms,%var);
}
sub _default_handler
{
	my $cms = shift;
	my %var = @_;
	my $module = 'sb::App::Feed';
	if ($module->isa('sb::App'))
	{
		return &sb::App::Feed::_common_parts($cms,%var);
	}
	$module = 'sb::App::Mobile';
	if ($module->isa('sb::App') and $var{'mode'} eq 'mob')
	{
		return &sb::App::Mobile::_common_parts($cms,%var);
	}
	return &sb::Content::_common_parts($cms,%var);
}
1;
__END__
